<?php
namespace App\Controller;

use App\Controller\AppController;

class OffresController extends AppController
{
    public $name = 'Offres';
    public function initialize()
    {
        parent::initialize();
        $this->loadComponent('Flash'); // Include the FlashComponent
    }
    public function index()
    {
        //categories
        $options = array(
            'order'=>array('Categories.id'=>'asc')
        );
        $categories = $this->Offres->Categories->find('all',$options);
        $this->set('categories',$categories);
        //offres
        $options = array(
            'order'=>array('Offres.id'=>'desc'),
            'limit' => 10
        );
        $offres = $this->Offres->find('all',$options)->contain(['Types']);
        $this->set('title','Emploi.com|Acceuil');
        $this->set('offres',$offres);
    }
    public function browse($category = null)
    {
        $conditions = array();
        if($category != null){
            $conditions[] = array(
                'Offres.category_id =' => $category
            );
        }
         //categories
        $options = array(
            'order'=>array('Categories.id'=>'asc')
        );
        $categories = $this->Offres->Categories->find('all',$options);
        $this->set('categories',$categories);
        //offres
        $options = array(
            'order'=>array('Offres.id'=>'desc'),
            'conditions'=>$conditions,
            'limit' => 10
        );
        $this->set('title','Emploi.com|Offres');
        $offres = $this->Offres->find('all',$options)->contain(['Types']);
        $this->set('offres',$offres);
    }
    public function find()
    {
        $conditions = array();
        if(!empty($this->request->data('keywords'))){
            $conditions[] = array('or'=>array(
                'Offres.title LIKE' => "%".$this->request->data('keywords')."%",
                'Offres.desc LIKE' => "%".$this->request->data('keywords')."%",
            ));
        }
        if(!empty($this->request->data('ville')) && $this->request->data('ville') != "default"){
            $conditions[] = array(
                'Offres.ville =' => $this->request->data('ville')
            );
        }
        if(!empty($this->request->data('categorie')) && $this->request->data('categorie') != "default"){
            $conditions[] = array(
                'Offres.category_id =' => $this->request->data('categorie')
            );
        }
         //categories
        $options = array(
            'order'=>array('Categories.id'=>'asc')
        );
        $categories = $this->Offres->Categories->find('all',$options);
        $this->set('categories',$categories);
        //offres
        $options = array(
            'order'=>array('Offres.id'=>'desc'),
            'conditions'=>$conditions,
            'limit' => 10
        );
        $offres = $this->Offres->find('all',$options)->contain(['Types']);
        $this->set('title','Emploi.com|Recherhce');
        $this->set('offres',$offres);
    }
    public function view($id){
         $conditions = array();
         //offres
         $query = $this->Offres->findById($id)->contain(['Types']);
         $offre = $query->first();
         $this->set('title',$offre->title);
         $this->set('offre',$offre);
    }
    public function add(){
        $categories = $this->Offres->Categories->find('list');
        $this->set('categories',$categories);
        $types = $this->Offres->Types->find('list');
        $this->set('types',$types);
        $offre = $this->Offres->newEntity();
        if($this->request->is('post')){
            //user id par default
            $this->request->data['user_id'] = $this->Auth->user('id');
            $this->request->data['created'] = date("Y-m-d h:s:i");
            //save data
            $offre = $this->Offres->patchEntity($offre, $this->request->data);
            if($this->Offres->save($offre)){
                $this->Flash->success(__('Offre ajoutée avec succés'),[
                    'params' => [
                        'class' => 'alert alert-success'
                    ]
                ]);
                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('Une erreur est survenue veuillez réessayer'),[
                'params' => [
                    'class' => 'alert alert-danger'
                ]
            ]);
        }
        $this->set('title','Emploi.com|Ajouter une offre');
        $this->set('offre',$offre);
    }
     public function edit($id){
        $categories = $this->Offres->Categories->find('list');
        $this->set('categories',$categories);
        $types = $this->Offres->Types->find('list');
        $this->set('types',$types);
        $offre = $this->Offres->get($id);
        if($this->request->is(['post','put'])){
            //user id par default
            if(empty($this->request->data('category_id')) || empty($this->request->data('category_id'))){
                $this->Flash->error(__('Veuillez choisir une catégorie et un type'),[
                    'params' => [
                        'class' => 'alert alert-danger'
                    ]
                ]);
                return $this->redirect(['action' => 'edit',$id]);
            }else{
                $this->request->data['user_id'] = 1;
                $this->request->data['created'] = date("Y-m-d h:s:i");
                //save data
                $offre = $this->Offres->patchEntity($offre, $this->request->data);
                if($this->Offres->save($offre)){
                    $this->Flash->success(__('Offre modifiée avec succés'),[
                        'params' => [
                            'class' => 'alert alert-success'
                        ]
                    ]);
                    return $this->redirect(['action' => 'index']);
                }
                $this->Flash->error(__('Une erreur est survenue veuillez réessayer'),[
                    'params' => [
                        'class' => 'alert alert-danger'
                    ]
                ]);
            }
        }
        $this->set('title',$offre->title);
        $this->set('offre',$offre);
    }
    public function delete($id)
    {
        $this->request->allowMethod(['post', 'delete']);
        $offre = $this->Offres->get($id);
        if ($this->Offres->delete($offre)) {
            $this->Flash->success(__('Offre avec le id: {0} est supprimée avec succés.', h($id)),[
                'params' => [
                    'class' => 'alert alert-success'
                ]
            ]);
            return $this->redirect(['action' => 'index']);
        }
    }
}