<?php

namespace App\Controller;

use App\Controller\AppController;
use Cake\Event\Event;

class UsersController extends AppController
{
    //allow to the user to have access to just some actions
    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['index','browse','view','find','register','logout']);
    }
    public function initialize()
    {
        parent::initialize();
        $this->loadComponent('Flash'); // Include the FlashComponent
    }
    public function register()
    {
        $user = $this->Users->newEntity();
        if ($this->request->is('post')) {
            $user = $this->Users->patchEntity($user, $this->request->data);
            if ($this->Users->save($user)) {
                $this->Flash->success(__('Utilisateur ajouté avec succés.'),[
                    'params' => [
                        'class' => 'alert alert-success'
                    ]
                ]);
                return $this->redirect(['action' => 'register']);
            }else  if($user->errors()){
                $error_msg = [];
                foreach( $user->errors() as $errors){
                    if(is_array($errors)){
                        foreach($errors as $error){
                            $error_msg[] = $error;
                        }
                    }else{
                        $error_msg[] = $errors;
                    }
                }
                if(!empty($error_msg)){
                   foreach($error_msg as $error){
                        $this->Flash->error(__($error),[
                            'params' => [
                                'class' => 'alert alert-danger'
                            ]
                        ]);
                   }
                }
            }else{
                $this->Flash->error(__("Impossible d'ajouter l'utilisateur."),[
                    'params' => [
                        'class' => 'alert alert-danger'
                    ]
                ]);
            }
        }
        $this->set('title','Emploi.com|Inscription');
        $this->set('user', $user);
    }
    public function login()
    {
        if ($this->request->is('post')) {
            $user = $this->Auth->identify();
            if ($user) {
                $this->Auth->setUser($user);
                return $this->redirect($this->Auth->redirectUrl());
            }
            $this->Flash->error(__('Email ou mot de passe est incorrect'),[
                'params' => [
                    'class' => 'alert alert-danger'
                ]
            ]);
        }
        $this->set('title','Emploi.com|Connexion');
    }

    public function logout()
    {
        return $this->redirect($this->Auth->logout());
    }
}